@@ -38,6 +38,13 @@ class PsycoPG2Adapter:
                 result = record_class(**dict(zip(column_names, result)))
         return result
 
+    @staticmethod
+    def select_value(conn, _query_name, sql, parameters):
+        with conn.cursor() as cur:
+            cur.execute(sql, parameters)
+            result = cur.fetchone()
+        return result[0] if result else None
+
     @staticmethod
     @contextmanager
     def select_cursor(conn, _query_name, sql, parameters):
@@ -69,3 +76,4 @@ class PsycoPG2Adapter:
     def execute_script(conn, sql):
         with conn.cursor() as cur:
             cur.execute(sql)
+            return cur.statusmessage
