@@ -1,3 +1,4 @@
+import inspect
 from types import MethodType
 from typing import Any, Callable, List, Optional, Set, Tuple, cast
 
@@ -12,18 +13,24 @@ def _params(args, kwargs):
 
 
 def _query_fn(
-    fn: Callable[..., Any], name: str, doc: Optional[str], sql: str, operation: SQLOperationType
+    fn: Callable[..., Any],
+    name: str,
+    doc: Optional[str],
+    sql: str,
+    operation: SQLOperationType,
+    signature: Optional[inspect.Signature],
 ) -> QueryFn:
     qfn = cast(QueryFn, fn)
     qfn.__name__ = name
     qfn.__doc__ = doc
+    qfn.__signature__ = signature
     qfn.sql = sql
     qfn.operation = operation
     return qfn
 
 
 def _make_sync_fn(query_datum: QueryDatum) -> QueryFn:
-    query_name, doc_comments, operation_type, sql, record_class = query_datum
+    query_name, doc_comments, operation_type, sql, record_class, signature = query_datum
     if operation_type == SQLOperationType.INSERT_RETURNING:
 
         def fn(self: Queries, conn, *args, **kwargs):
@@ -72,21 +79,23 @@ def _make_sync_fn(query_datum: QueryDatum) -> QueryFn:
     else:
         raise ValueError(f"Unknown operation_type: {operation_type}")
 
-    return _query_fn(fn, query_name, doc_comments, sql, operation_type)
+    return _query_fn(fn, query_name, doc_comments, sql, operation_type, signature)
 
 
 def _make_async_fn(fn: QueryFn) -> QueryFn:
     async def afn(self: Queries, conn, *args, **kwargs):
         return await fn(self, conn, *args, **kwargs)
 
-    return _query_fn(afn, fn.__name__, fn.__doc__, fn.sql, fn.operation)
+    return _query_fn(afn, fn.__name__, fn.__doc__, fn.sql, fn.operation, fn.__signature__)
 
 
 def _make_ctx_mgr(fn: QueryFn) -> QueryFn:
     def ctx_mgr(self, conn, *args, **kwargs):
         return self.driver_adapter.select_cursor(conn, fn.__name__, fn.sql, _params(args, kwargs))
 
-    return _query_fn(ctx_mgr, f"{fn.__name__}_cursor", fn.__doc__, fn.sql, fn.operation)
+    return _query_fn(
+        ctx_mgr, f"{fn.__name__}_cursor", fn.__doc__, fn.sql, fn.operation, fn.__signature__
+    )
 
 
 def _create_methods(query_datum: QueryDatum, is_aio: bool) -> List[Tuple[str, QueryFn]]:
